package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.34.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.34.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@("`0`````````````#`!8````!````````(I@`````````0```````
M`+&(``````!``#@`"0!``!H`&0````8````$`````````$``````````0```
M``````!``````````?@````````!^``````````(`````P````0````````"
M.`````````(X`````````C@`````````#P`````````/``````````$````!
M````!0```````````````````````````````````````*1`````````I$``
M```````0``````$````&````````J\````````"[P````````+O`````````
M!,`````````$Z````````!```````@````8```````"KT````````+O0````
M````N]`````````"``````````(```````````@````$````!`````````)(
M`````````D@````````"2`````````!$`````````$0`````````!&1TY5``
M```$````````G9````````"=D````````)V0`````````-P`````````W```
M```````$9'3E40````8`````````````````````````````````````````
M`````````````````````!!D=.52````!````````*O`````````N\``````
M``"[P`````````1`````````!$```````````2]L:6(O;&0V-"YS;RXQ````
M```$````%`````-'3E4`X&GNA+?I(7KSX01IBJ=^M1HO\%(````$````$```
M``%'3E4```````````,````"```````````````1````1`````0````(A`1`
M!0`0$""$`(:`!``"*`@$(`D```F""`(`ND$0@(@`````````1````$<```!*
M````2P```%(```!3````5`````````!6````5P```%@```!9````6@```%P`
M`````````!_?Q6XM1][.?)I_:[:;Q2Y\U&34#N3_(1Q8<=D!QD?B;XL!LL#C
M2ZR'U_I"+#_EPGR2X[I@;*'[UD,):V;,KV?LU45"TW`'B>W;8C/,)8P5"Y<Z
M#9N<J7\*`J?@4)X::TG[X*,`````````````````````````````````````
M`P``"P```````!D(``````````````-K$@``````````````````````````
M``#<$@````````````````````````````*W$0``````````````````````
M``````*'$@````````````````````````````"#$@``````````````````
M``````````#1$0````````````````````````````%5$@``````````````
M``````````````&M$@````````````````````````````#R$@``````````
M``````````````````)Y$@````````````````````````````'F$@``````
M```````````````````````!(`````````````````````````````%L$@``
M``````````````````````````*_$@````````````````````````````&4
M$@````````````````````````````';$@``````````````````````````
M``$C$@````````````````````````````'4$@``````````````````````
M``````$3$@````````````````````````````$%$@``````````````````
M``````````',$@````````````````````````````*M$@``````````````
M```````````````0(`````````````````````````````%S$@``````````
M``````````````````(.$@````````````````````````````*U$0``````
M``````````````````````)<$@`````````````````````````````L(```
M``````````````````````````(\$@````````````````````````````!&
M$@````````````````````````````(7$@``````````````````````````
M``%%$@````````````````````````````&F$@``````````````````````
M``````!C$@````````````````````````````#`$@``````````````````
M``````````!T$@````````````````````````````&<$@``````````````
M``````````````)C(@````````````````````````````*<$@``````````
M``````````````````&/$@````````````````````````````"D$@``````
M``````````````````````'M$@````````````````````````````'S$@``
M``````````````````````````$W$@````````````````````````````#F
M$@````````````````````````````%^$@``````````````````````````
M``)R$@````````````````````````````(M$@``````````````````````
M``````([$@````````````````````````````'%$@``````````````````
M``````````'Z$@````````````````````````````"/$@``````````````
M``````````````'A$@````````````````````````````%@$@``````````
M``````````````````#A$@````````````````````````````&V$@``````
M``````````````````````"S$0````````````````````````````&]$@``
M``````````````````````````*.$@````````````````````````````(?
M$@````````````````````````````$L$@``````````````````````````
M``)_$@````````````````````````````!4$@``````````````````````
M``````)#$@````````````````````````````*5$@``````````````````
M``````````)5$0````````````````````````````-T$@``#0```````$#H
M`````````1````/)$@``#0```````#:P````````!Z0```)0$@``#0``````
M`"!(`````````E````+K$@``#0```````"N(``````````8```,)$@``#0``
M`````#Y8`````````HH```/O$@``#0```````"N0`````````B0```.O$```
M%P```````,"```````````````+\$@``#0```````"VX`````````#8```,?
M$@``#0```````#3@`````````)````.`$0``#P```````%RH``````````0`
M``.<$@``#0```````%GH`````````3@```.G$@``#0```````"IP````````
M`#P```/$$```%P```````,"H``````````````/=$@``#0```````#6@````
M`````0H```./$```%@```````,````````````````-#$@``#0```````"WP
M`````````0P```/6$```%@```````,"```````````````/\$0``%@``````
M`,!X``````````@```.5$@``#0```````"*8``````````````.[$@``#0``
M`````%EX`````````&P```.1(```%@```````,````````````````-9$@``
M#0```````#5P`````````"X```,M$@``#0```````"JP`````````-0```-/
M$@``#0```````%L@`````````48```0&$@``#0```````"\`````````!=P`
M7U]G;6]N7W-T87)T7U\`7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE`%])
M5$U?<F5G:7-T97)434-L;VYE5&%B;&4`4&5R;%]S>7-?=&5R;0!097)L7W-Y
M<U]I;FET,P!097)L7V%T9F]R:U]L;V-K`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?
M9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?<W9?<V5T<'9N`%!,
M7V1O7W5N9'5M<`!097)L7VYE=UA37V9L86=S`%!,7W1H<E]K97D`<&5R;%]F
M<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V7W-E
M='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7VYE=UA3`'!E<FQ?
M9&5S=')U8W0`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E
M<WES;6%L;&]C`'!E<FQ?86QL;V,`7U]S=&%C:U]C:&M?9F%I;`!E>&ET`&QS
M965K-C0`<F5A9&1I<C8T`'-T<F1U<`!C;&]S961I<@!O<&5N-C0`<W1R<F-H
M<@!U;FQI;FL`;65M;6]V90!S=')T;VL`<FUD:7(`<F5A9`!S=')S='(`;6MD
M:7(`9V5T<&ED`'!T:')E861?9V5T<W!E8VEF:6,`<F5A9&QI;FL`<F5A;&QO
M8P!?7W-P<FEN=&9?8VAK`%]?9G!R:6YT9E]C:&L`;'-T870V-`!?7VQI8F-?
M<W1A<G1?;6%I;@!S=&1E<G(`;65M8VAR`%]?8WAA7V9I;F%L:7IE`'-T<F-H
M<@!C;&]S90!O<&5N9&ER`&=E='5I9`!A8V-E<W,`;65M8W!Y`%]?97)R;F]?
M;&]C871I;VX`<W1R;F-M<`!?7V5N=FER;VX`7U]R96=I<W1E<E]A=&9O<FL`
M;&EB<&5R;"YS;RXU+C,T`&QI8F,N<V\N-@!P87)?8W5R<F5N=%]E>&5C`'!A
M<E]B87-E;F%M90!84U]);G1E<FYA;'-?4$%27T)/3U0`<&%R7V5N=E]C;&5A
M;@!P87)?8W5R<F5N=%]E>&5C7W!R;V,`<&%R7V1I<FYA;64`<VAA7V9I;F%L
M`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`%])3U]S
M=&1I;E]U<V5D`%]?9&%T85]S=&%R=`!S:&%?=7!D871E`'AS7VEN:70`7U]B
M<W-?<W1A<G0`<VAA7VEN:70`7V5N9`!P87)?;6MT;7!D:7(`7V5D871A`'!A
M<E]S971U<%]L:6)P871H`'!A<E]F:6YD<')O9P!M>5]P87)?<&P`<&%R7VEN
M:71?96YV`$=,24)#7S(N,S0`1TQ)0D-?,BXT`$=,24)#7S(N,S,`1TQ)0D-?
M,BXS+C(`1TQ)0D-?,BXR``````````(``0`"``(``0`!``$``@`!``(``@`!
M``(``P`"``(``0`"``$``0`"``(``0`!``(``@`"``$`!``!``(``0`"``$`
M`0`!``(``@`"``(``0`"``(``0`!``4``@`%``0``@`&``$``@`!``(``@`!
M``(``@`%``$``@`!``8``@`"``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$```````$`!0```N$````0``````:6
MD;0````&```$$P```!`-:6D4````!0``!!X````0!I:1LP````0```0H````
M$`EI&7(````#```$,P```!`-:6D2`````@``!#\`````````````N\``````
M````#````````".(````````N\@`````````#````````"-`````````O_@`
M````````#````````"!(````````P`@`````````#````````,`(````````
MP!@`````````#````````%^"````````P"``````````#````````%T$````
M````P#``````````#````````%VD````````P#@`````````#````````%VH
M````````P$``````````#````````%]V````````P$@`````````#```````
M`%T*````````P%``````````#````````%]^````````P&``````````#```
M`````%]F````````P&@`````````#````````%]L````````P'@`````````
M#````````%^(````````OZ`````$````"@``````````````````OZ@````'
M````"@``````````````````O[`````*````"@``````````````````O[@`
M```-````"@``````````````````O\`````8````"@``````````````````
MO\@````=````"@``````````````````O]`````A````"@``````````````
M````O]@````C````"@``````````````````O^`````G````"@``````````
M````````O^@````Z````"@``````````````````O_````!#````"@``````
M````````````O>@````"````"P``````````````````O?`````#````"P``
M````````````````O?@````%````"P``````````````````O@`````&````
M"P``````````````````O@@````(````"P``````````````````OA`````)
M````"P``````````````````OA@````+````"P``````````````````OB``
M```,````"P``````````````````OB@````.````"P``````````````````
MOC`````/````"P``````````````````OC@````0````"P``````````````
M````OD`````1````"P``````````````````OD@````2````"P``````````
M````````OE`````3````"P``````````````````OE@````4````"P``````
M````````````OF`````5````"P``````````````````OF@````6````"P``
M````````````````OG`````7````"P``````````````````OG@````9````
M"P``````````````````OH`````:````"P``````````````````OH@````<
M````"P``````````````````OI`````>````"P``````````````````OI@`
M```?````"P``````````````````OJ`````@````"P``````````````````
MOJ@````B````"P``````````````````OK`````D````"P``````````````
M````OK@````E````"P``````````````````OL`````F````"P``````````
M````````OL@````G````"P``````````````````OM`````H````"P``````
M````````````OM@````I````"P``````````````````ON`````J````"P``
M````````````````ON@````K````"P``````````````````OO`````L````
M"P``````````````````OO@````M````"P``````````````````OP`````N
M````"P``````````````````OP@````O````"P``````````````````OQ``
M```P````"P``````````````````OQ@````Q````"P``````````````````
MOR`````R````"P``````````````````OR@````S````"P``````````````
M````OS`````T````"P``````````````````OS@````U````"P``````````
M````````OT`````V````"P``````````````````OT@````W````"P``````
M````````````OU`````X````"P``````````````````OU@````Y````"P``
M````````````````OV`````[````"P``````````````````OV@````\````
M"P``````````````````OW`````]````"P``````````````````OW@````^
M````"P``````````````````OX`````_````"P``````````````````OX@`
M``!`````"P``````````````````OY````!!````"P``````````````````
MOY@```!"````"P``````````ZV_P,``DN00`'Z?[_V#C$/```"3`P```4EK`
M$```4TOC$!````2Y`@`1IX0``PWAXT#Q$``$ZV_PT``$!_0'!^,0\#@`),`0
M``!20=('\#`0".,0$!``!`?Q!P`'``<`P!```%)`XQ`0```$!_$-$.,0$`P`
M%,#T____Y0````#`$```4C3C$!````0'\0T0XQ`0#``4P/3____5````&,`0
M``!2*.,0$```!`?Q#1#C$!`,`!3`]/___\4````PP!```%(<XQ`0```$!_$-
M$.,0$`P`%,#T____M0```$C`$```4A#C$!````0'\0T0XQ`0#``4P/3___^E
M````8,`0``!2!.,0$```!`?Q#1#C$!`,`!3`]/___Y4```!XP!```%'XXQ`0
M```$!_$-$.,0$`P`%,#T____A0```)#`$```4>SC$!````0'\0T0XQ`0#``4
MP/3___]U````J,`0``!1X.,0$```!`?Q#1#C$!`,`!3`]/___V4```#`P!``
M`%'4XQ`0```$!_$-$.,0$`P`%,#T____50```-C`$```4<CC$!````0'\0T0
MXQ`0#``4P/3___]%````\,`0``!1O.,0$```!`?Q#1#C$!`,`!3`]/___S4`
M``$(P!```%&PXQ`0```$!_$-$.,0$`P`%,#T____)0```2#`$```4:3C$!``
M``0'\0T0XQ`0#``4P/3___\5```!.,`0``!1F.,0$```!`?Q#1#C$!`,`!3`
M]/___P4```%0P!```%&,XQ`0```$!_$-$.,0$`P`%,#T___^]0```6C`$```
M48#C$!````0'\0T0XQ`0#``4P/3___[E```!@,`0``!1=.,0$```!`?Q#1#C
M$!`,`!3`]/___M4```&8P!```%%HXQ`0```$!_$-$.,0$`P`%,#T___^Q0``
M`;#`$```45SC$!````0'\0T0XQ`0#``4P/3___ZU```!R,`0``!14.,0$```
M!`?Q#1#C$!`,`!3`]/___J4```'@P!```%%$XQ`0```$!_$-$.,0$`P`%,#T
M___^E0```?C`$```43CC$!````0'\0T0XQ`0#``4P/3___Z%```"$,`0``!1
M+.,0$```!`?Q#1#C$!`,`!3`]/___G4```(HP!```%$@XQ`0```$!_$-$.,0
M$`P`%,#T___^90```D#`$```413C$!````0'\0T0XQ`0#``4P/3___Y5```"
M6,`0``!1".,0$```!`?Q#1#C$!`,`!3`]/___D4```)PP!```%#\XQ`0```$
M!_$-$.,0$`P`%,#T___^-0```HC`$```4/#C$!````0'\0T0XQ`0#``4P/3_
M__XE```"H,`0``!0Y.,0$```!`?Q#1#C$!`,`!3`]/___A4```*XP!```%#8
MXQ`0```$!_$-$.,0$`P`%,#T___^!0```M#`$```4,SC$!````0'\0T0XQ`0
M#``4P/3___WU```"Z,`0``!0P.,0$```!`?Q#1#C$!`,`!3`]/___>4```,`
MP!```%"TXQ`0```$!_$-$.,0$`P`%,#T___]U0```QC`$```4*CC$!````0'
M\0T0XQ`0#``4P/3___W%```#,,`0``!0G.,0$```!`?Q#1#C$!`,`!3`]/__
M_;4```-(P!```%"0XQ`0```$!_$-$.,0$`P`%,#T___]I0```V#`$```4(3C
M$!````0'\0T0XQ`0#``4P/3___V5```#>,`0``!0>.,0$```!`?Q#1#C$!`,
M`!3`]/___84```.0P!```%!LXQ`0```$!_$-$.,0$`P`%,#T___]=0```ZC`
M$```4&#C$!````0'\0T0XQ`0#``4P/3___UE```#P,`0``!05.,0$```!`?Q
M#1#C$!`,`!3`]/___54```/8P!```%!(XQ`0```$!_$-$.,0$`P`%,#T___]
M10```_#`$```4#SC$!````0'\0T0XQ`0#``4P/3___TU```$",`0``!0,.,0
M$```!`?Q#1#C$!`,`!3`]/___24```0@P!```%`DXQ`0```$!_$-$.,0$`P`
M%,#T___]%0``!#C`$```4!CC$!````0'\0T0XQ`0#``4P/3___T%```$4,`0
M``!0#.,0$```!`?Q#1#C$!`,`!3`]/___/4```1HP!```%``XQ`0```$!_$-
M$.,0$`P`%,#T___\Y0``!(#`$```3_3C$!````0'\0T0XQ`0#``4P/3___S5
M```$F,`0``!/Z.,0$```!`?Q#1#C$!`,`!3`]/___,4```2PP!```$_<XQ`0
M```$!_$-$.,0$`P`%,#T___\M0``!,C`$```3]#C$!````0'\0T0XQ`0#``4
MP/3___RE```$X,`0``!/Q.,0$```!`?Q#1#C$!`,`!3`]/___)4```3XP!``
M`$^XXQ`0```$!_$-$.,0$`P`%,#T___\A0``!1#K;_`P`"3C\/\X_W'C,/"H
M`"3C0/"@`"10(/"T04#PH$$P\*A!(/"TLD\`L.N[`"``#;)/`+'2!_#`L"C`
MY?___[+$2```3Y/$*```3Z2Y!``TP.4``!WGQ!@``$^DE0`0`*>$`*K$J```
M3WWC(*```!;`Y?___N>Y!``2XR"@```6E@(4>L#E___^W5B@\+26`21Z["H`
M!`#8N10`(NLB``,`#<#E___^_N,P\*@`!.,0,```!.,0(```),`0```?+>,0
M(`@`)*>J``/$&```3[+C$"`0`"3$*P``3[C`$```'Q[C$"`8`"2Y!`!26"#P
MM*<N``&GQ`"A03`P"*<(``3L0O__`-BY%``0XY`P```$ZQ$``P`-XY%0```D
MIPH``:<[``BG1O_Q[!(``P#8N10`$>L1``,`#4$14`"Y%`!*Y4@0````IVD`
M`,`P```$,L0H``!/@\#E___\)!BB$B*GA`!$Q"@``$]Y09#PO,#E___]^,`@
M```=S+D$`#G`Y0```.2Y`@`BIX0`.<0H``!/9<#E___[UL#E___]([D4`"K5
M!_#`L"BG=`!0ZV_P^``$!_[`Y?___-7$*P``3TZY`@`BIX0`/<#E___]2\2H
M``!.R.,@H```%L#E___^,I(`*B>G]/]#Q"@``$\WP.7___Q8&**G]/^WP!``
M`$\JXR`0```"IX0`!\#E```/2J?T_[ZY!``YP"```!U2P.4```"4Q"L``$\5
MN0(`(J>$_Z^G]/_LIQ@`!*?T_WJG*0`!P.7___U.P.7___VK04#P".,P\```
M!*<)__"Y@`#PI_O_4-<'\`#P`.OO\*``)$%P\*"G:0``IUD``,`@``!.F>,@
M(```!,#E___^FP``!P<'!P<'P!```$[0P"```$[-N2``$@>.Q!@``$YGN0(`
M$0>.!_'`(```3L#`$```3KVY"0`2ZR$``P`*ZS$`/P`,N0@`,NLS``$`"KD"
M`#,'CL08``!.3KD"`!$'CL`@``!.I`?QZ[_P6``DP+```$Z=X_#_8/]QE0"P
M`*=T`!7`$```3D/C$!````*GA``(Q"@``$Y/P.7___R\P.7___^UD@&P`.N_
M\/@`!`?^P/3___^\!P?K;_`P`"3C\/]@_W&Y`@""IX0`6L08``!-_N-P$```
M`J>$`%*Y!`!CXQ"```"4N00`F)4`@`"GA`!/IQX`/:>$``M!D)`!XQ"0``"4
ME0"0`*=T__4;F..@<````J>$`!^Y%`"9N00`M[D$`$FY!``XN00`*L#E___[
MPA(BIW0`"$$9H`"5/1``IX0`#T&PL`CCH+````*G=/_IN00`*NMO\-``!`?^
M0:F@`;GI<!NY!``JZQ$``P`*4!!@`.MO\-``!`?^IZD``+D$`"KK;_#0``0'
M_J>8``"G]/^_!P<'!^NO\%``)./P_LC_<;)/`+"Y!`"BZ[L`(``-03#PH+)/
M`+'2!_$PL"C`Y?___-@2(J=T`!\8$E@@\+C`*P``\`"G+D``IX0`!\(M``"@
M`*=T`!*Y!``JISD``L#E___]3Q`2IQK__X@0`!^G]``$IQ@``+D4`"'5!_$P
ML"BG=``&ZZ_QB``$!_[`Y?___'@'!^MO\#``)./P_L#_<;)/`*#KJ@`@``VR
M3P"AN0(`8M('\3B@**>$``:5`&``IW0`"]4'\3B@**=T`)/K;_%P``0'_L#E
M___]0[D"`+*GA/_RN00`*\#E___[NKD"`"*GA`!D09`@$Y4N(!.G=``&E0"0
M`:>$_^^5+B`3IX0`8J<(``"Y!``6IRD``+)>`"&G%/_^N00`.:<9``"Y"0`F
MLEX`$Z<4__ZY"0`9&B&G*@`"N10`(L#E___Z6N.0\*``),!0```;=KD$`)*G
M2?__ISD``<#E___\V[D$`"E!,/"HP.7___L4IR[__[D$`"FGA``+6!#PP,`;
M``#P`*<>0`"GA``IP.7___PRN00`*<#E___\?;D$`"O`Y?__^UBY`@`BIW3_
MH+D$`"O`Y?__^>^Y!``FP.7___I*I_3_>Y4ND`&G=/^>E0"0`J>$_X.G]/^8
MP.7___]7I_3_V<#E___[Q@<'!P<'!^M_\#@`)./P_UC^<>,0\*`!<;D$`+*Y
M!`"CLD\`D$&`\*#KF0`@``VY!``XLD\`D:=)#__`(```&PO2!Q``D"C`Y?__
M^I`2(J?$`!'L$O__`-@80KD4`"%!(O"@E0`@`*=T`"(2$:=T`![$&```3&OC
M(!```!;`Y?__^]6Y!`!*N00`.\#E___Z+N,0\*`!<=4'$`"0**=T`"KK?_#@
M`00'_AA!N10`=*<Y`"^Y!`!'N00`*,#E___Z9KD"`"*GA/_6Q!@``$P_XR`0
M```6P.7___NIN00`5[D$`$BY!``[P.7___L`I_3_TL#E___[2^MO\#``)./P
M_TC_<;)/`&#K9@`@``VR3P!AN00`LKD$`*/2!_"P8"B5/3``IW0`!$&@,`&G
M"```N00`&J>)``"R7@"!IQ3__KD)`(I!,/"LN00`*\#E___]\KD"`"*GA`"=
MIP@``*<9``"Y!``RLEX`$Z<4__ZY"0`2N2$`@:?$`'KC</"L`!3$V```2^#K
M=P`#``WC(+```)2Y!``;E0"P`*=T``VG]`#N01`0`>,@$```E)4`$`"GA``&
MIRX`/:=T__6Y"0`;N10`$4$H$`*Y!`"7XY#0```(P.7___D;XR"0```DN0(`
M(J>$`#OC$+```)#C(-````3C-R````1"$#``0;"P`1A!N0(`$:=T`!"G]``_
MXQ"P``"00A`@`4&PL`$80;D"`!&GA``S0D#PH+D$`".5/?"@03`P`:=T_^R2
M/2``IQD``.,QH```D$(Q(`&G&P`!N0(`,Z=T__?5!_"P8"BG=`"8ZV_PZ``$
M!_ZG&0``XS&@``"00C$@`*<;``&Y`@`SIW3_]Z?T_^JY!``CI_3_U\38``!+
M6.-PT```!.,0<````J>$`'"Y!``7IY@``!@IIYH``4$0$`CC,!````*G=/_X
MIRH``[D4`"+K(@`#``W`$```2ZSC$!```!*G=``WP!```$NDY4P0```!P.7_
M__B.N0(`$N,0\*``)*>$_ZZY!``WN10`>>MW``,`#;D$`$?`Y?__^/OC$/"@
M``3C$-```"10D/"LXQ#PH``$IYH``;D4`)GKF0`#``U!&1``Y4@0````I_3_
M([D$`#*Y!``GP.7___E+XR#PH``DXR#0```DN0(`(J>$_WBY%`!YZW<``P`-
MI_3_UZ<9``"G]/\CIRD`$*>8``"G]/^CP.7___G]!P<'!^MO\#``)./P_UC_
M<<2X``!*TN,@L```%L!@```:IL#E___Z.>,@L```%L#E___Z,\!0```YK,1(
M``!*T<`P```91\#E___ZM^,@L```%L#E___Z(;D$`%;E2/"@``#`0```"@'`
M,```&4'`Y?__^1/K;_#8``0'_NOO\'``),08``!*F>/P_V#_<>,@$```%L#E
M___Z`,!0```Y><1(``!*GL`P```9%.OO\1``!,#T___Z@0<'!P?K;_`P`"3C
M\/](_7'C$/"P`G&R3P"0ZYD`(``-LD\`D=('$`"0*$&P\*[C@/"O`7'`Y?__
M^53`$```&0WC$/"@`"2Y!`!BP%```!C_ITD0`:<Y``&Y!``KP.7___I`N00`
M*[D$`#BG21``P.7___A7$B*G1``MN00`LJ<J``&Y%``BP.7___>;N0(`HJ>$
M`""Y%`"[N00`.+D$`$O`Y?__^FY!&Z``D@`0`.,0\+`"<=4'$`"0**=T``BY
M!``JZV_PZ`($!_[`Y?__^3FGJ0``I_3_[0<'!P?`]/___Y0'!^MO\#``)./P
M_K#^<>,0\4@!<;D$`+*Y!`"3LD\`<$$P\+3K=P`@``W`(```&*>R3P!QT@<0
M`'`HP.7___ODISD`+[D$`**Y!``KP.7___D7N0(`(J>$`!C`(```&)2Y!``[
MP.7___VSN00`*^,0\4@!<=4'$`!P**=T`-/K;_&``00'_KD$`"G`Y?__^"C`
M,```&(#`Y?__]W*Y`@!BIX3_W4&0\4A!@/"XE0!@`*>$`(JY`@"JIX0`#J<(
M``"Y!``6N00`*K)=`!*G%/_^IX0`:KD$`!:G"```IRD``+)>`"&G%/_^XQ`O
M__]QN0D`)KGI8#&Y(0!AIZ0`&94O$`"G=``)D@`0`.,0'___<:<W__>G"```
MIRD``+D$`!:R7@`AIQ3__KD)`":G"```IQD``+D$`#NR7@`3IQ3__KD)`!M!
M$2`!PAX```__IR3_AL`0```8(..P\*@`).,0\*``),!0```8@:=)$`"G.0`!
MN00`*<#E___Y0KD$`#BY!``IP.7___=[$B*G=``,6!#PT,`;``#P`,(=``"`
M`*>$`"?`,```%_:G*0``P.7___;FN0(`8J>$_U&5`&``IW3_>KD"`*JGA``&
ME2Z@`*>$``FG*0`!P&```!?/I_3_IY4`H`&GA/_?I_3_]:<Y``&Y!``IP.7_
M__CR$B*G=/_3N00`.<`@```7OL#E___\W[D$`"G`Y?__]V*G]/\IP.7___@=
M!P<'!^N_\%@`)*<Y`"_C\/]@_W&Y!`"RP.7___B^N0(`(J>$``1!L"`!N00`
M*^N_\/@`!,#T___W0`<'ZY_P2``DX_#_6/YQLD\`H.,0\*`!<>NJ`"``#;)/
M`*'2!Q``H"BY`@`RIX0`594`,`"GA`!1IP@``*>9``"Y!``3LEX`D:<4__ZY
M"0"3[$D``0#9PDX``!``IR0`4D&P\*"Y!``KP.7___CIXQF___]QN>FP(;DA
M`!NGQ``-E2\0`*=T``F2`!``XQ`?__]QIR?_]Z<Y`"^Y!``KP.7___A>N0(`
M(J>$`!>Y(0`KIR0`)+D$`"O`Y?__]N'C$/"@`7'5!Q``H"BG=``?ZY_P\`$$
M!_[C$/"@`7'5!Q``H"BG=``3P"```!<8ZY_P\`$$P/3___;$D@`@`*?T_]RG
M*0``I_3_W<#E___W>0<'!P?KK_!0`"3C\/]0_W&R3P"@0;#PI.NJ`"``#;)/
M`*'2!_"HH"BY!``[P"```!;]P.7___HQN0(`(J>$`##$*```2#+C$/"D`!3K
M$0`#``WC$"````CC(!`(``3C(!```"2Y`@`BIX3_X.,@$!``!.,@$`@`)$$0
M$`BY`@`BIW3_]KD$`#O`(```%L_`Y?__^@.Y`@`BIW3_U+D$`#O`(```%LC`
MY?__^?>Y`@`BIX0`,,0H``!'^.,0\*0`%.L1``,`#>,0(```".,@$`@`!.,@
M$```)+D"`"*GA/_@XR`0$``$XR`0"``D01`0"+D"`"*G=/_VN00`.\`@```6
MFL#E___YR;D"`"*G=/_4N00`.\`@```6DL#E___YO;D"`"*GA``PQ"@``$>^
MXQ#PI``4ZQ$``P`-XQ`@```(XR`0"``$XR`0```DN0(`(J>$_^#C(!`0``3C
M(!`(`"1!$!`(N0(`(J=T__:Y!``[P"```!9DP.7___F/N0(`(J=T_]2Y!``[
MP"```!9=P.7___F#N0(`(J>$`##$*```1X3C$/"D`!3K$0`#``WC$"````CC
M(!`(``3C(!```"2Y`@`BIX3_X.,@$!``!.,@$`@`)$$0$`BY`@`BIW3_]KD$
M`#O`(```%B_`Y?__^56Y`@`BIW3_U+D$`#O`(```%B?`Y?__^4FY`@`BIX0`
M,,0H``!'2N,0\*0`%.L1``,`#>,0(```".,@$`@`!.,@$```)+D"`"*GA/_@
MXR`0$``$XR`0"``D01`0"+D"`"*G=/_VN00`.\`@```5^<#E___Y&[D"`"*G
M=/_4N00`.\`@```5]<#E___Y#[D"`"*GA``PQ"@``$<0XQ#PI``4ZQ$``P`-
MXQ`@```(XR`0"``$XR`0```DN0(`(J>$_^#C(!`0``3C(!`(`"1!$!`(N0(`
M(J=T__:Y!``[P"```!7'P.7___CAN0(`(J=T_]2Y!``[P"```!63P.7___C5
MN0(`(J>$`##$*```1M;C$/"D`!3K$0`#``WC$"````CC(!`(``3C(!```"2Y
M`@`BIX3_X.,@$!``!.,@$`@`)$$0$`BY`@`BIW3_]KD$`#O`(```%67`Y?__
M^*>Y`@`BIW3_U+D$`#O`(```%8?`Y?__^)NY`@`BIX0`,,0H``!&G.,0\*0`
M%.L1``,`#>,0(```".,@$`@`!.,@$```)+D"`"*GA/_@XR`0$``$XR`0"``D
M01`0"+D"`"*G=/_VN00`.\`@```56<#E___X;;D"`"*G=/_4N00`.\`@```5
M4L#E___X8;D"`"*GA``PQ"@``$9BXQ#PI``4ZQ$``P`-XQ`@```(XR`0"``$
MXR`0```DN0(`(J>$_^#C(!`0``3C(!`(`"1!$!`(N0(`(J=T__:Y!``[P"``
M`!4DP.7___@SN0(`(J=T_]2Y!``[P"```!4=P.7___@GN0(`(J>$`##$*```
M1BCC$/"D`!3K$0`#``WC$"````CC(!`(``3C(!```"2Y`@`BIX3_X.,@$!``
M!.,@$`@`)$$0$`BY`@`BIW3_]KD$`#O`(```%._`Y?__]_FY`@`BIW3_U+D$
M`#O`(```%+#`Y?__]^VY`@`BIX0`,,0H``!%[N,0\*0`%.L1``,`#>,0(```
M".,@$`@`!.,@$```)+D"`"*GA/_@XR`0$``$XR`0"``D01`0"+D"`"*G=/_V
MN00`.\`@```4@L#E___WO[D"`"*G=/_4N00`.\`@```4KL#E___WL[D"`#*G
MA``(P"```!2:P.7___F-N00`.\`@```4I<#E___WH;D"`#*GA``(P"```!2D
MP.7___E[N00`.\`@```4HL#E___WC[D"`#*GA``9P"```!1#P.7___EIU0?P
MJ*`HIW0`(L`P```4GL`@```45>NO\0``!,#T___Y6+D$`#O`(```%(?`Y?__
M]VRY`@`RIX3_Y<`@```43L#E___Y1J?T_]W`Y?__](D'!P<'Z[_P6``DX_#_
M4/]QLD\`L.N[`"``#;)/`+'$+0``18NG+O__T@?PJ+`HIX0`#;D4`"+5!_"H
ML"BG=``IZ[_Q"``$!_Y!,/"DP"```!0=P.7___<QN0(`(J>$`!6_$2``IX0`
M$<`7````,+F$`!&Y`P`A["(_OP%5Q"\``$5<I_3_V*<H``"G]/_YP.7___0_
MZ^_P<``DX_#_8/]QP.7___(6P.7___'SN0(`(J>$``7C("````3K[_$0``0'
M_@<'ZV_P,``DX_#_0/]QLD\`H+D$`&+KJ@`@``U!,/"TLD\`H<`@```4"=('
M\+B@*,#E___VX;D"`+*GA``8E0"P`*>$`!2Y!``VP.7___(PN0(`(J>$`!O5
M!_"XH"BG=`!4ZV_P\``$!_[5!_"XH"BG=`!+N00`-L`@```3W^MO\/``!,#T
M___XFZ<(``"Y!``6N00`.[)>`"&G%/_^IQD``+D)`":R7@`3IQ3__KD)`!M!
M(A`"P.7___(*P!```!-BX[#PJ``DXQ#PH``DN00`LL!0```3PJ=)__^G.0`!
MP.7___2%U0?PN*`HIW0`#;D$`#O`(```$Z'K;_#P``3`]/__^%W`Y?__\Z('
M!P<'!P>R3P`PZS,`(``-LD\`,>MO\#``)./P_?CW<>,P\,``),`0``!$H.-`
M\@`(<;D$`))!H/#,T@=``#`HT@_PT!`(P"```!,+N00`.M('\.`0&-(O\0`0
M(-(/\.@04-('\/@08,#E___V/[D"`+*GA``&E0"P`*=T`F3`Y?__\4#`Y?__
M\1VY`@`BIX0!'>.P(````J>$`1BG"```IRD``+D$`!NR7@`AIQ3__KD)`"OK
M(@`!``VG*P`!P.7___&`E0"P`.-@L```E+D$`'*Y!`""IX0`&[D4`&:Y!``G
MP%```!,PITG__Z<Y``'`Y?__\_=!L+`!07!P`N-@L```E)4`L`"G=/_I06#Q
M",`@```2]:?T``FG:P`(XR!O^/\"IX0`'KD$`#K`Y?__]=VY`@"RIX3_\I4`
ML`"GA/_NP.7___9"$B*GA/_HN00`*\#E___R-KD"`&*G=``<0;#PT.-@L```
M`J>$`!65`&``IX0`I[D$`";`Y?__]B82(J=T`)*GNP`(XV"P```"IW3_[Z<(
M``"Y!``6I]D``+)>`-&G%/_^N00`**<9``"Y"0#6LEX`$J<4__ZY"0`8&M&G
MV@0$N10`?;D$`"?`Y?__\/C`$```$K_C$/"H`"3C@/"P`"3`$```$DCC$/"@
M`"2Y!`""P%```!*IITG__Z<Y``'`Y?__\VVY!``HISD!P,#E___R5J<N__^G
M=``+P.7___(?6!`@`*<>`!&G=`%P03#Q,+D$`"C`Y?__\K(8LA(BIW0`"U@0
M\4C`&P``\`"G'D``IX0`?L08``!#=KD$`&CC4)````3`0```$I7C(!````2G
M.0`!P.7___*"IWD``.,0\,``!.,@\@`(<=4'(``0**=T`H>Y!``GZV_R.`@$
M!_ZGNP`(N00`)L#E___QB+D"`&*GA/]6I_3_;*=I``"G]/]H08#PZ.,@@```
M`J>$`!:Y!``ZP.7___4&N0(`$J>$``:5`!``IW0`&:>+``CC((````*G=/_N
MIRD`#<"P```2',#E___P6Z=H`%.Y!`!RN00`@J?T_N#`Y?__\5"Y`@"RIX3_
MY*<(``"G*0``N00`&[)>`"&G%/_^N0D`*^LB``$`#:<K``&G]/ZX6&#Q3,#E
M___OU!EBIW3_?E@0\4C`&P```?^G'@'`IW3_=;D$`"?`Y?__\".Y!``ZN00`
M<L`@```2,<#E___TK;D"`#*GA`#LXR"0```$P.7___BCN0(`8J>$`.*G"```
MIQD``+D$`":R7@`2IQ3__KD)`!:G'@`#I\0`'KD4`"'`,```$@[C(F_\_W&R
M70`RIQ3__J=T`!"G'@`$IX0!@J<:__NY%``101%@`)4O$`"GA`%XQ!T``$*P
MIQ[__Z>$`5(2$:>$`+?`,```$8?`(```$4S`Y?__]D2Y!`!HP.7___%7P!``
M`!(^XQ#PL``DXR#PJ``DP!```!$7P%```!'>XQ#PH``DITG__Z<Y``&Y!``G
MP.7___(\I_0`,L#E___P]U@0(`"G'@`1IW0`-*>Z``&Y!`!HP.7___$JP!``
M`!(1XQ#PN``DXR#PJ``DP!```!#JXQ#PH``DP%```!&UN10`&Z=)___C$/"P
M`"2G.0`!N00`)\#E___R"J<Y`<"Y!``GP.7___#SIR[__Z>$_\>Y!``HP.7_
M__&ZN00`-\`@```0M,#E___UVKD$`"?`Y?___/FG]/Z]N10`$>,0\*``)+D$
M`&C$&```0A7C4)````3`0```$1CC(!````2G.0`!P.7___$CI_3^H<#E___\
MVN,0\,``!.,@\@`(<=4'(``0**=T`26Y!``KZV_R.`@$P/3___`KXV"0```$
MI_3_'<`0``!!]^5,$````+D$`":G.0``P.7___%YN00`DABB$B*GA/]`ITD`
M`J<Y_^[`Y?__[RQ!L/(`ITD`!KD$`#NY!``IP.7___$QE0#R`*=T``:50_(!
MIX0`MKD$`"FG20``ISD``+D4`*K`Y?__[P[`Y0``#G.Y!`"2I_0`"[D4`$*Y
M!``[N00`*<#E```.GJ5/@`"Y!``[N00`*L#E___Q!1(BIR3_[;D$`"JGN0`4
MP.7__^ZKN00`.4$@\<-!H/'7N00`DL#E```/'.-@D```D+D$`"K`4```$'JG
MFP`!ITG__Z<Y``&GJP`"P.7___$]I[?_[<`0```1(N,0\+``))(`\?]!$/'7
MN00`:.,0\*@`),`0```/]>,0\*``),!0```0L:=)__^G.0`!N00`)\#E___Q
M&J?T_QNY!``ZP"```!``P.7___,4N0(`(J>$_UB_$2``IX3_5,`7````,+F$
M`!&Y`P`1ZQ$`/P`,Q!\``$$_I_3^D^,@D`@``J>$_H>G"```IQD``+D$`#*R
M7@`3IQ3__KD)`!+"'@````.GQ/YVXS$O_/]QP!```!!HLET`$Z<4__ZYXH!B
MI_3^:)5!\@*G=/]*E4/R`Z=T_T:52/($IW3_0I5%\@6G=/\^ITD``J<Y_\:Y
M!``IN00`:,#E___N2KD$`"FG20`IN00`.\#E___P4<`0```0F..P\*@`).,0
M\+``),`0```/<>,0\*``)*?T_WS`Y?__[\T'!P<'ZW_P.``DX_#_4/]QQ+@`
M`$"BLD\`D.,@L```%NN9`"``#;)/`)'2!_"HD"A!@/"DP.7___``N00`HN,@
ML```%L#E___O^+D$`!*Y!``XP"````]0T@`0L:"PP.7___)ON0(`(J>$``:5
M,2``IX0`X<#E___X'.,@L```%L#E___OVJ=9``.G20`!P#````_YP.7__^X@
MN0(`HJ>$`![C(+```!;`Y?__[\;C$*`0``3`0```#^?C,!````3`Y?__[AKC
M$*`0``3C$!````210!`-IW0`R.,@L```%L#E___OJJ=9``.G20`!P#````_-
MP.7__^WPN0(`HJ>$`""Y!``XP"````[;P.7___(86!"P`+D"`'*Y%@`AIX0`
MD,#E___OB>,0H!``!+D$`$?C,!````3`Y?__[=[C(+```!;`Y?__[WBY!`"B
MXR"P```6P.7__^]PITD``<`P```/EL#E___M",!````/F[D$`#*Y!``JP.7_
M_^V^XR"P```6P.7__^]8D@`@L;D$`#C`(```#I#`Y?__\=+$*P``0%.Y!`"R
MN0(`(J>$`"ZG.0'`N00`*\#E___NKNP2``$`V,(?`````:?$`!:G+@`1IX0`
M$L08``!`,[D$`%*Y!`!+P"````]RXS`0```$P.7__^\RU0?PJ)`HIW0`1NM_
M\.@`!`?^Q"@``$`:P.7___LGQ"L``$`8N00`LKD"`"*G=/_'P"````]`P.7_
M_^\4E0`@`:>$_R*G]/\=P.7__^[[Q!@``#_\XR"@$``$XS`0```$XR`@```$
MP.7___+<I_3_;N,@L```%L#E___NY.,0H!``!.,P$```!,#E___N>Z?T_RO`
MY?__[H8'!P<'!P?KG_!(`"3C\/]0_W&R3P"@N00`DNNJ`"``#;)/`*'2!_"H
MH"C`Y?__]G*G.0`ON00`LL#E___O%[D"`"*GA``$0;`@`;D$`"O`Y?__[9S$
M'0``/VVY!`"RIQ[__Z>$`!82$:>$``JY`@"9IX0`!I4`D`"G=``JU0?PJ*`H
MIW0`1^N?\/@`!`?^03#PI,`@```-]\#E___Q"[D"`"*GA``OOQ$@`*>$`"O`
M%P```#"YA``1N0,`$>L1`#\`#,0?```_-J?T_\^Y!``KITD`!,`P```.(\#E
M___LYA(BIW3_S=4'\*B@**=T`!*Y!``IZY_P^``$P/3___&2P!```#\7Y4P0
M````I_3_N,#E___M^T%0(#BG20`(ZV_P,``DX_#\T/]QLD\`H$$P\*CKJ@`@
M``VR3P"AT@?S**`HXQ!0```$ZP$`(``,XP`P```DP!H`````XQ`P"``D05!0
M"*<[`!"G1__MXS#Q$``$XX#Q&``$XU#Q(``$XY#PJ``$XV#PL``$04#PN*<)
M`$"Y!`!UX[!````$N00`&^,00#``@KF"`!.Y@@`9[%$@OR%5[%$@/@%6XU!`
M<``DN00`.+D$`):Y!`"'ITL`"*<'"USCL"`8``3CD/"P``3"FEJ">9FY"`";
MXT`@```$XP`@"``$XP#PH``DXU`@$``$[#0@OR55ZW```@`,[#0@.@56['``
M(1Y6[(<@OP!5N>>`%;F``!2Y@@`5N>B0T;GGL)6Y@`"0N8(`F^,0\*@`!,(:
M6H)YF>,0("``"+D(`!/K-``"``RY"``9[#0`(1Y6[)$@OP!5N><P9^P1.[\E
M5;F``&GL&0`Z!5:Y@@!HN0@`'>QQ(+\`5>S1.[\E5>S7`#H%5N,0\+@`!.,`
M\,``!,(:6H)YF<(*6H)YF;D(`!6Y"``(N0@`%NN)``(`#.QC(+\`5>R)`"$>
M5KD(`!VY@@`X[-$[OR55[)$@OP!5N>1P$[D$`#WCT/#(``3L.0`Z!5;"VEJ"
M>9FY@@`6N0@`$+GH8`VY"``3[&@@OP!5[-$[OR55ZS<``@`,[#<`(1Y6N8(`
M@^QQ(+\`5;GDD!BY!`"-X]#PT``$[(<`.@56PMI:@GF9N8(`%KD(`!"YZ&`-
MN0@`&.QC(+\`5>S1.[\E5>N)``(`#.R)`"$>5KF"`#CLD2"_`%6YY'`3N00`
M/>/0\-@`!.PY`#H%5L+:6H)YF;F"`!:Y"``0N>A@#;D(`!/L:""_`%7LT3N_
M)57K-P`"``SL-P`A'E:Y@@"#['$@OP!5N>20&+D$`(WCT/#@``3LAP`Z!5;"
MVEJ">9FY@@`6N0@`$+GH8`VY"``8[&,@OP!5[-$[OR55ZXD``@`,[(D`(1Y6
MN8(`..R1(+\`5;GD<!.Y!``]X]#PZ``$[#D`.@56PMI:@GF9N8(`%KD(`!"Y
MZ&`-N0@`$^QH(+\`5>S1.[\E5>LW``(`#.PW`"$>5KF"`(/L<2"_`%6YY)`8
MN00`C>/0\/``!.R'`#H%5L+:6H)YF;F"`!:Y"``0N>A@#;D(`!CL8R"_`%7L
MT3N_)57KB0`"``SLB0`A'E:Y@@`X[)$@OP!5N>1P$[D$`#WCT/#X``3L.0`Z
M!5;"VEJ">9FY@@`6N0@`$+GH8`VY"``3[&@@OP!5[-$[OR55ZS<``@`,[#<`
M(1Y6N8(`@^QQ(+\`5;GDD!BY!`"-X]#Q```$[(<`.@56PMI:@GF9N8(`%KD(
M`!"YZ&`-N0@`&.QC(+\`5>S1.[\E5>N)``(`#.R)`"$>5KF"`#CLD2"_`%6Y
MY'`3N00`/>/0\0@`!.PY`#H%5L+:6H)YF;F"`!:Y"``0N>A@#;D(`!/L:""_
M`%7LT3N_)57K-P`"``SL-P`A'E:Y@@"#['$@OP!5N>20&+D$`(WCT/$0``3L
MAP`Z!5;"VEJ">9FY@@`6N0@`$+GH8`VY"``8[&,@OP!5[-$[OR55ZXD``@`,
M[(D`(1Y6N8(`..R1(+\`5;GD<!.Y!``]X]#Q&``$[#D`.@56PMI:@GF9N8(`
M%KD(`!"YZ&`-N0@`$^QH(+\`5>S1.[\E5>LW``(`#.PW`"$>5KF"`(/L<2"_
M`%6YY)`8N00`C>/0\2``!.R'`#H%5L+:6H)YF;F"`!:Y"``0N>A@#;D(`!CL
M8R"_`%7LT3N_)57KB0`"``SLB0`A'E:Y@@`X[)$@OP!5N>1P$[D$`#WCT/$H
M``3L.0`Z!5;"VEJ">9FY@@`6N0@`$+GH8`VY"``3[&@@OP!5[-$[OR55ZS<`
M`@`,[#<`(1Y6N8(`@^QQ(+\`5;GDD!BY!`"-X]#Q,``$[(<`.@56PMI:@GF9
MN8(`%KD(`!"YZ&`-N0@`&.QC(+\`5>S1.[\E5>N)``(`#.R)`"$>5KF"`#CL
MD2"_`%6YY'`3N00`/>/0\3@`!.PY`#H%5L+:6H)YF;F"`!:Y"``0N>A@#;D(
M`!/LV""_`%7K-P`"``SL-P`A'E:YYS!HXX#Q0``$PHI:@GF9['$[OR55N8``
M:>QQ(#H%5KF"`&W`&@````"Y"`!@N>C0".R#(+\`5;D(`&?K>0`"``SL>0`A
M'E;LECN_)56YYW#3[)8@.@56N8``T>,P\4@`!+F"`-C".F[9ZZ&Y"``XZX$`
M`@`,[($`(1Y6N>>`%[F"`!:Y"`#0N1H`,;D(`-GLG3N_)57LG2`Z!5:SP0`)
ML\T`$+D(`#'L$SN_)57L$R`Z!5;CD/%0``2SP0`!PIINV>NAN1H`E^QV(K\^
M5>QV`B$>5KGG<!BY@@`=[&TBOSY5N1H`D>QM`B$>5K/-`!"Y"`"1XQ#Q6``$
MPAINV>NAN1H`&.S9.[\E5>S9(#H%5KGG8(>Y@@"#N1H`&+D(`!WLT3N_)57L
MT2`Z!5;C@/%@``2SP0`-PHINV>NAN1H`A^QS(K\^5>QS`B$>5KGG<-:Y@@#9
ML\T``+D:`(WC,/%H``3".F[9ZZ&Y&@`V[&DBOSY5[&D"(1Y6N>=@U[F"`-&Y
M"`"`N1H`/>R8.[\E5>R8(#H%5K/!``FSS0``N0@`,.S3.[\E5>S3(#H%5N.0
M\7``!+/!``W"FF[9ZZ&Y&@"7['$BOSY5['$"(1Y6N>=PUKF"`-BSS0``N1H`
MG>,0\7@`!,(:;MGKH;D:`!;L:"*_/E7L:`(A'E:YYV#7N8(`T[D(`)"Y&@`=
M[(D[OR55[(D@.@56L\$`"+/-``"Y"``0[-$[OR55[-$@.@56XX#Q@``$L\$`
M#<**;MGKH;D:`(?L<R*_/E7L<P(A'E:YYW#6N8(`V;/-``"Y&@"-XS#QB``$
MPCINV>NAN1H`-NQI(K\^5>QI`B$>5KGG8->Y@@#1N0@`@+D:`#WLF#N_)57L
MF"`Z!5:SP0`)L\T``+D(`##LTSN_)57LTR`Z!5;CD/&0``2SP0`-PIINV>NA
MN1H`E^QQ(K\^5>QQ`B$>5KGG<-:Y@@#8L\T``+D:`)WC$/&8``3"&F[9ZZ&Y
M&@`6[&@BOSY5[&@"(1Y6N>=@U[F"`-.Y"`"0N1H`'>R).[\E5>R)(#H%5K/!
M``BSS0``N0@`$.S1.[\E5>S1(#H%5N.`\:``!+/!``W"BF[9ZZ&Y&@"'[',B
MOSY5[',"(1Y6N>=PUKF"`-FSS0``N1H`C>,P\:@`!,(Z;MGKH;D:`#;L:2*_
M/E7L:0(A'E:YYV#7N8(`T;D(`("Y&@`][)@[OR55[)@@.@56L\$`";/-``"Y
M"``P[-,[OR55[-,@.@56XY#QL``$L\$`#<*:;MGKH;D:`)?L<2*_/E7L<0(A
M'E:YYW#6N8(`V+/-``"Y&@"=XQ#QN``$PAINV>NAN1H`%NQH(K\^5>QH`B$>
M5KGG8->Y@@#3N0@`D+D:`!WLB3N_)57LB2`Z!5:SP0`(L\T``+D(`!#LT3N_
M)57LT2`Z!5;C@/'```2SP0`-PHINV>NAN1H`A^QS(K\^5>QS`B$>5KGG<-:Y
M@@#9L\T``+D:`(WC,/'(``3".F[9ZZ&Y&@`V[&DBOSY5[&D"(1Y6N>=@U[F"
M`-&Y"`"`N1H`/>R8.[\E5>R8(#H%5K/!``FSS0``N0@`,.S3.[\E5>S3(#H%
M5N.0\=``!+/!``W"FF[9ZZ&SS0``N1H`E^QQ(K\^5>QQ`B$>5KGG<-:Y@@#8
MXQ#QV``$N1H`G<(:;MGKH;D(`)"Y&@`6[-@BOSY5[&D@OP!5[-@"(1Y6[`D[
MOR55N>?0A^P&`#H%5KF"`(.Y&@`8N0@`$.R#(K\^5>R#`B$>5N,P\>``!+GG
M@`W".F[9ZZ&Y@@"0N1H`-^QQ(+\`5>P1.[\E5>P7`#H%5KD:`#GCD/'H``2Y
M"``QPIJ/&[S<ZQ8``@`,N1H`G>P6`"$>5NS1(+\`5;GDT`BSP0`I[&,[OR55
M[),@OP!5N>80.+F``#>Y@0`PXP#Q\``$P@J/&[S<[&D`.@56L\$``+/-``*Y
M"``PL\T``+D(`#:Y&@`(ZV<``@`,[&<`(1Y6N>30=KF!`!:Y@``9N8$`%^-P
M\?@`!+D(`!#">H\;O-RYZ-`'[(,@OP!5L\$`(.PS.[\E5>PX`#H%5KD(`#'K
M&0`"``SL&0`A'E;LT2"_`%6YY-`&N>80EKF``)BY@0"0XP#R```$P@J/&[S<
ML\$``.QS(+\`5;/-``*Y"`"0[#,[OR55L\T``+D:``;K:``"``SL:``A'E:Y
MY-"&[#<`.@56N8$`%KF``!>Y@0`8XX#R"``$N0@`$,**CQN\W+GHT`BY"`"3
ML\$`(.PY(+\`5>N'``(`#.R9.[\E5>R'`"$>5NR3`#H%5NQX(+\`5;D(`!FY
MY'`&[-$@OP!5[)$[OR55N>:`%NR=`#H%5KF``!.Y@0`0XP#R$``$P@J/&[S<
ML\$``+/-``*Y"``0N0@`&>N3``(`#.R3`"$>5KGFD#BYY'")N8``/;/-``"Y
M@0`XN1H`!NQA(+\`5;D(`##L$3N_)57L%@`Z!5:Y"``Q[(,@OP!5ZQT``@`,
M[!T`(1Y6N>80";/!``#L,SN_)57C`/(8``3L.``Z!5;""H\;O-RSP0`CN00`
M,+D(`#>SP0!#L\T`!.S1(+\`5;/-`#"YY-!YN8``-KF!`#>Y"``PL\T``N-P
M\B``!+D(`##">H\;O-RY&@!YZY8``@`,L\$`!^R6`"$>5K/-``"YY-!IN8$`
M&;F``!BY@0`6XV#R*``$N0@`$,)JCQN\W+GHT`;L<R"_`%6SP0`@[#,[OR55
M[#<`.@56N0@`,>L8``(`#.P8`"$>5NS1(+\`5;GDT`GL8R"_`%7L@SN_)56Y
MYA`YN8``-[F!`##C`/(P``3""H\;O-RSP0``L\T``KD(`#"SS0``N1H`">N7
M``(`#.R7`"$>5KGDT'GLA@`Z!5:Y@0`9N8``%KF!`!?C</(X``2Y"``0PGJ/
M&[S<N>C0![D(`#BSP0`@[(,@OP!5[#,[OR55[#@`.@56N0@`,>L6``(`#.P6
M`"$>5NS1(+\`5;GDT`GL<R"_`%7L8SN_)56YYA`YN8``.+F!`##C`/)```3"
M"H\;O-RSP0``L\T``KD(`#"SS0``N1H`">N8``(`#.R8`"$>5KGDT(GL9P`Z
M!5:Y@0`9N8``%[F!`!CC@/)(``2Y"``0PHJ/&[S<N>C0"+D(`#:SP0`@[&,@
MOP!5[#,[OR55[#8`.@56N0@`,>L7``(`#.P7`"$>5NS1(+\`5;GDT`GL@R"_
M`%7L<SN_)56YYA`YN8``-KF!`##C`/)0``3""H\;O-RSP0``L\T``KD(`#"S
MS0``N1H`">N6``(`#.R6`"$>5KGDT&GL>``Z!5:Y@0`9N8``&+F!`!;C8/)8
M``2Y"``0PFJ/&[S<N>C0!KD(`#>SP0`@[',@OP!5[#,[OR55[#<`.@56N0@`
M,>L8``(`#.P8`"$>5NS1(+\`5;GDT`GL8R"_`%7L@SN_)56YYA`YN8``-[F!
M`##C`/)@``3""H\;O-RSP0``L\T``KD(`#"SS0``N1H`">N7``(`#.R7`"$>
M5KGDT'GLA@`Z!5:Y@0`9N8``%KF!`!?C</)H``2Y"``0PGJ/&[S<N>C0![D(
M`#BSP0`@[(,@OP!5[#,[OR55[#@`.@56N0@`,>L6``(`#.P6`"$>5NQA(+\`
M5;GD8`GL<R"_`%7LTSN_)56YYA`YN8``.+F!`##C`/)P``3""H\;O-RSP0``
ML\T``KD(`#"SS0``N1H`">N8``(`#.R8`"$>5KGD8(GLUP`Z!5:Y@0`9N8``
M%[F!`!CC@/)X``3"BH\;O-RY"``0N0@`/;GH8`CLTR"_`%7L,SN_)57L/0`Z
M!5:Y"``Q[(,[OR55[(,@.@56ZQ<``@`,L\$`".P7`"$>5NR!(+\`5;GD@&FY
MYA!YN8``?;F!`';C8/*```2Y"`!PPFJ/&[S<L\T``+D:`&FYZ`"7L\$`)NM]
M``(`#.QI.[\E5>Q]`"$>5NQI(#H%5KGD@`?`.@````"Y!`#6N8$`%^-@\H@`
M!+F``!/":LIBP=:Y@0`0N>B`!N-@\I``!+/!``#":LIBP=:SS0`"N1H`9[D(
M`!#K@P`"``RY"``=[(,`(1Y6L\T``+GG@-?L,3N_)56Y@@#9[#$@.@56N1H`
M#;/!`":Y"``P[&,[OR55[&,@.@56['DBOSY5L\$`1NQY`B$>5N/0\I@`!+GG
M<&C"VLIBP=:Y@@!AN1H`V+/-``2SP0`-L\T`DKD:`);L82*_/E7L80(A'E:Y
MYV#7N8(`T[D(`)"SS0``[!D[OR55N1H`#>P9(#H%5KD(`!#LT3N_)57LT2`Z
M!5;C@/*@``2SP0`-PHK*8L'6N1H`A^QS(K\^5>QS`B$>5KGG<-:Y@@#9L\T`
M`+D:`(WC,/*H``3".LIBP=:Y&@`V[&DBOSY5[&D"(1Y6N>=@U[F"`-&Y"`"`
MN1H`/>R8.[\E5>R8(#H%5K/!``FSS0``N0@`,.S3.[\E5>S3(#H%5N.0\K``
M!+/!``W"FLIBP=:Y&@"7['$BOSY5['$"(1Y6N>=PUKF"`-BSS0``N1H`G>,0
M\K@`!+D(`)#"&LIBP=;LV3N_)56Y&@`6[-D@.@56[&@BOSY5[&@"(1Y6N>=@
MA[F"`(.SP0`-N1H`&+/-``#CT/+```2Y"``0PMK*8L'6[($[OR55N1H`U^R!
M(#H%5NQS(K\^5;/!``CL<P(A'E:SS0``N>=PAN,P\L@`!+F"`(G".LIBP=:Y
M&@`VN00`;>S9(K\^5;D:`&BY"`!@[-D"(1Y6N>?0E[F"`)'LACN_)56Y&@`Y
MN00`F.R6(#H%5KD(`#GC@/+0``3LDSN_)57LDR`Z!5;"BLIBP=:SP0`)N1H`
MA[/-``#L<2*_/E7L<0(A'E;C$/+8``2YYW"=PAK*8L'6N8(`EKD:`!WLUB*_
M/E7LU@(A'E:YY]!GN8(`8[D:`(FY&@`6N0@`@.R8.[\E5>R8(#H%5K/!``FS
MS0``N0@`$.QA.[\E5>QA(#H%5N.0\N``!+/!``;"FLIBP=:Y&@"7[',BOSY5
M[',"(1Y6N>=P;;F"`&BSS0``N1H`EN,P\N@`!.QH(K\^5<(ZRF+!UNQH`B$>
M5KD:`#VYYV#7N8(`T;D(`)"Y&@`][(D[OR55[(D@.@56L\$`"+/-``"Y"``P
M[-,[OR55[-,@.@56XX#R\``$L\$`#<**RF+!UKD:`(?L<2*_/E7L<0(A'E:Y
MYW#6N8(`V;/-``"Y&@"-XQ#R^``$PAK*8L'6N1H`%NQI(K\^5>QI`B$>5KGG
M8->Y@@#3N0@`@+D:`!WLF#N_)57LF"`Z!5:SP0`)L\T``+D(`!#LT3N_)57L
MT2`Z!5;CD/,```2SP0`-PIK*8L'6N1H`E^QS(K\^5>QS`B$>5KGG<-:Y@@#8
ML\T``+D:`)VY"`"0[-D[OR55[-D@.@56XS#S"``$L\$`#<(ZRF+!UK/-``"Y
M&@`VX]#S$``$[&@BOSY5PMK*8L'6[&@"(1Y6N1H`U[GG8(>Y@@"!N1H`.+D(
M`##L<SN_)57L<R`Z!5;L@2*_/E6SP0`'[($"(1Y6L\T``+GG@':Y@@!YN1H`
MU^,0\Q@`!.QY(K\^5<(:RF+!UNQY`B$>5KD:`!:YZ`!MN>=P"+D$`-?CT"`@
M``C`V@````#CT"`@`"3LEB"_`%6YYS#0[`8[OR55N1H`'>P)`#H%5KD(`!#L
MTR*_/E7LTP(A'E;C,/,@``2YY]`'PCK*8L'6N>BP?;D(`#2YYV"P[$$@OP!5
MN1H`..R!.[\E5;D$`!/LA``Z!5:Y&@`;N0@`&,`:`````.,0(```),!Z````
M`.-P(!@`).,P\*``!.L9``(`#+D(`#3L&0`A'E;`.@````#C,"`(`"2Y"``5
MP!H`````XQ`@$``DU0?S**`HIW0`"NMO\V``!`?^N00`:Z?T](/`Y?__XCOK
M[_!P`"2G*0"`X_#_8/]QP.7__^!PP#%G12,!XS`@```DY4@@*```P#_OS:N)
MXS`@"``DY4@@,```P#^8NMS^XS`@$``DY4P@>```P#$0,E1VXS`@&``DP#_#
MTN'PXS`@(``DZ^_Q$``$!_X'!P<'ZV_P,``DZQ0``P`-N00`DN,@("@`!+D(
M`!+L42"_`%6Y!`"$X_#_8/]QXT"0,``$N00`L[DQ`"&GQ``$ITL``>-0D"@`
M).L8`!T`#+D(`!3C$)`P`"1!<)`XXR"0>``2IW0`/:>.`#^GQ`!D[&C_P`#8
MB&``!NP6``$`V.P1'[D&5>RA_\``V4'1L`#KJ@`&``RGJP`!TC]P`+``N00`
M*4&PL$#`Y?__\[:GI__VIXK_P(E@``8;AKD4`(BY!``]N00`)[D$`$C`Y?__
MXKQ0@)!XZV_PT``$!_ZGJ`!`&Z(9J+D$`!>Y\C"HN1@`$KD$`#NY!``AN10`
M:KD$`$;`Y?__XJ$8&EH0D'A0$)!XIQX`0*=T_^"Y^:"HN0@`MKD4`(JY!``I
MP.7___-UI_3_G+D$`-NG]/_$ZX_P0``DN00`L^.`,"@`!..0,#``!.PX.K\]
M5;D4`!-!$;`XDH`0`*<Z``'C\/]@_W&Y%``3N00`HD$1L#BG/@`XI\0`3J=(
M`$"Y^3`D&4.GA``/IRK__^LR``@`WA(SIW0`8;D6`"+&(````&FY!``KP.7_
M__,SUS>P.+`XIQD``.P9``=@5>P9"`]@5>P9$!=@5>P9&!\@5;D$`"OL@0`?
M`%7C@+!P`"3`Y?__\Q>Y!``KT@.@`+`$T@.@!+`,T@.@"+`4T@.@#+`<T@.@
M$+`DZX_PX``$P/3__^&(IT@`.+GY,"090Z>$_\NG*O__ZS(`"`#>$C.G=``)
MN18`(L8@````(*?T_[SC(!0``#;7_Q``$`!!$!$`IS;_^*?T_^_C(!0``#;7
M_Q``$`!!$!$`IS;_^*?T_Y?7`!``$`#7`!``$``'!\18```QT,#T___?#0<'
M!P?K;_`P`"2Y!``?I_O_8.,0\```),#````PH@<'XT#Q$``$ZV_PT``$!_0'
M!P```````@`!)7,O)7,`+W!R;V,O<V5L9B]E>&4``$1Y;F%,;V%D97(Z.F)O
M;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5```+W!R;V,O)6DO
M)7,`97AE`"X`4$%27U1%35```%!!4E]04D]'3D%-10``.@`O`%!%4DPU3$E"
M``!015),3$E"`%!%4DPU3U!4``!015),24\``%!!4E])3DE424%,25I%1`!0
M05)?4U!!5TY%1`!005)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?
M1TQ/0D%,7T1%0E5'``!005)?1TQ/0D%,7U1-4$1)4@!005)?5$U01$E2``!0
M05)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@``,0!,1%],24)205)9
M7U!!5$@`4UE35$5-```E,#)X```E<R5S)7,E<P``<&%R+0``)7,Z(&-R96%T
M:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\]
M)6DI"@``)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H
M<&QE87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@``
M4$%42```<&%R;```+G!A<@``)7,E<V-A8VAE+25S)7,``"5S)7-T96UP+25U
M)7,`)7,E<W1E;7`M)74M)74E<P``&`!P97)L```P`%!!4CHZ4&%C:V5R.CI6
M15)324].```Q+C`U-@!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R
M>0``)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y
M("5S(&9A:6QE9"`H97)R;F\])6DI"@``+64``"TM``!54T52``!54T523D%-
M10``5$5-4$1)4@!435``+W1M<```979A;"`G97AE8R`O=7-R+V)I;B]P97)L
M("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@
M<V]M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)%!!4E]-04=)0RP@
M)$9)3$5?;V9F<V5T7W-I>F4L("1#04-(15]M87)K97(L("1C86-H95]N86UE
M7W-I>F4I.PI"14=)3B!["B1005)?34%'24,@/2`B7&Y005(N<&U<;B(["B1&
M24Q%7V]F9G-E=%]S:7IE(#T@-#L@("`C('!A8VLH(DXB*0HD8V%C:&5?;6%R
M:V5R(#T@(EPP0T%#2$4B.PHD8V%C:&5?;F%M95]S:7IE(#T@-#`["GT*<W5B
M(&9I;F1?<&%R7VUA9VEC"GL*;7D@*"1F:"D@/2!`7SL*;7D@)&-H=6YK7W-I
M>F4@/2`V-"`J(#$P,C0["FUY("1B=68["FUY("1S:7IE(#T@+7,@)&9H.PIM
M>2`D<&]S(#T@)'-I>F4@+2`D<VEZ92`E("1C:'5N:U]S:7IE.R`@("`@(",@
M3D]413H@)'!O<R!I<R!A(&UU;'1I<&QE(&]F("1C:'5N:U]S:7IE"G=H:6QE
M("@D<&]S(#X](#`I('L*<V5E:R`D9F@L("1P;W,L(#`["G)E860@)&9H+"`D
M8G5F+"`D8VAU;FM?<VEZ92`K(&QE;F=T:"@D4$%27TU!1TE#*3L*:68@*"AM
M>2`D:2`](')I;F1E>"@D8G5F+"`D4$%27TU!1TE#*2D@/CT@,"D@>PHD<&]S
M("L]("1I.PIR971U<FX@)'!O<SL*?0HD<&]S("T]("1C:'5N:U]S:7IE.PI]
M"G)E='5R;B`M,3L*?0IM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F
M:6QE+"`E36]D=6QE0V%C:&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]
M*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M
M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S
M96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<5M296UO=FEN9R!F
M:6QE<R!I;B`B)'!A<E]T96UP(ETI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H
M<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*
M<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G
M35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%4
M12`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA
M;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI
M.PIM>2`D9FEL96YA;64@/2`D=&UP+3YF:6QE;F%M93L*<')I;G0@)'1M<"`\
M/"(N+BXB.PIX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@
M)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R
M96%K"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<D9FEL
M96YA;64G"BXN+@IC;&]S92`D=&UP.PIC:&UO9"`P-S`P+"`D9FEL96YA;64[
M"FUY("1C;60@/2`B)&9I;&5N86UE(#XO9&5V+VYU;&P@,CXF,2`F(CL*<WES
M=&5M*"1C;60I.PIO=71S*'%Q6U-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S
M('1O('!E<F9O<FT@8VQE86YU<#H@)&9I;&5N86UE72D["GT*?2!]"D)%1TE.
M('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA
M;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U
M:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)7-Y<R`]("@*<&%T:%]S97`@
M("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@
M("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X
M92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O
M(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*;W5T<RAQ<5M<
M)'!R;V=N86UE(#T@(B1P<F]G;F%M92)=*3L*7W-E=%]P87)?=&5M<"@I.PIO
M=71S*'%Q6UPD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2)=*3L*
M;7D@*"1S=&%R=%]P;W,L("1D871A7W!O<RD["DU!1TE#.B!["FQO8V%L("13
M24=[7U]705).7U]](#T@<W5B('M].PIU;FQE<W,@*&]P96X@7T9(+"`G/#IR
M87<G+"`D<')O9VYA;64I('L*;W5T<RAQ<5M#86XG="!R96%D(&9R;VT@9FEL
M92`B)'!R;V=N86UE(ETI.R`@(R!D;VXG="!U<V4@)"$@:&5R92!A<R!I="!R
M97%U:7)E<R!%<G)N;RYP;0IL87-T($U!1TE#.PI]"FUY("1M86=I8U]P;W,@
M/2!F:6YD7W!A<E]M86=I8R@J7T9(*3L*:68@*"1M86=I8U]P;W,@/"`P*2![
M"F]U=',H<7%;0V%N)W0@9FEN9"!M86=I8R!S=')I;F<@(B1005)?34%'24,B
M(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0SL*?0IO=71S*")&
M;W5N9"!005(@;6%G:6,@870@<&]S:71I;VX@)&UA9VEC7W!O<R(I.PIS965K
M(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE+"`P.PIR96%D
M(%]&2"P@)&)U9BP@)$9)3$5?;V9F<V5T7W-I>F4["FUY("1O9F9S970@/2!U
M;G!A8VLH(DXB+"`D8G5F*3L*;W5T<R@B3V9F<V5T(&9R;VT@<W1A<G0@;V8@
M1DE,17,@:7,@)&]F9G-E="(I.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&
M24Q%7V]F9G-E=%]S:7IE("T@)&]F9G-E="P@,#L*)&1A=&%?<&]S(#T@=&5L
M;"!?1D@["FUY("5R97%U:7)E7VQI<W0["G)E860@7T9(+"`D8G5F+"`T.R`@
M("`@("`@("`@("`@("`@("`@("`@("`@(",@<F5A9"!T:&4@9FER<W0@(D9)
M3$4B"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@
M-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L
M;&YA;64@/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN9R!&24Q%("(D9G5L;&YA
M;64B+BXN72D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD
M77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I
M(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L
M("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*
M:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\
M86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D8W)C)&5X="(L
M("1B=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M
M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N
M86UE?2`]("1F=6QL;F%M93L*?0IE;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO
M/W-H;&EB+WP@86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@*2!["FUY("1F
M:6QE;F%M92`](%]S879E7V%S*"(D8F%S96YA;64D97AT(BP@)&)U9BP@,#<U
M-2D["F]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PI]"F5L<V4@>PHD36]D
M=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D
M8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*)')E<75I<F5?;&ES='LD9G5L
M;&YA;65]*RL["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]
M("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R
M968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&EN9F\@/2`D36]D=6QE0V%C
M:&5[)&UO9'5L97T["G)E='5R;B!U;FQE<W,@)&EN9F\["F1E;&5T92`D<F5Q
M=6ER95]L:7-T>R1M;V1U;&5].PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O
M)&EN9F\O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN
M960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?
M=&UP9FEL92!O<B!D:64@(D-A;B=T(&-R96%T92!T96UP(&9I;&4Z("0A(CL*
M)&9H+3YB:6YM;V1E*"D["B1F:"T^<')I;G0H)&EN9F\M/GMB=69]*3L*)&9H
M+3YS965K*#`L(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA
M;64@/2!?<V%V95]A<R@B)&EN9F\M/GMC<F-]+G!M(BP@)&EN9F\M/GMB=69]
M*3L*)&EN9F\M/GMF:6QE?2`]("1F:6QE;F%M93L*;W!E;B!M>2`D9F@L("<\
M.G)A=R<L("1F:6QE;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&5N
M86UE(CH@)"%=.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F
M86EL960Z(&-A;B=T(&9I;F0@;6]D=6QE("1M;V1U;&4A(CL*?2P@0$E.0RD[
M"G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER
M92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ
M2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*
M=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES
M="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE
M(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@
M>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N
M;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID
M96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]"G5N;&5S<R`H)&)U
M9B!E<2`B4$M<,#`S7#`P-"(I('L*;W5T<RAQ<5M.;R!Z:7`@9F]U;F0@869T
M97(@1DE,12!S96-T:6]N(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-
M04=)0R`["GT*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@("`@("`@
M("`@("`@("`C('-T87)T(&]F('II<`I]"FUY($!P87)?87)G<SL*;7D@*"1O
M=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.
M5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@
M<V5C=7)I='D@<')O8FQE;2D*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP
M72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M
M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U
M;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII
M9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`
M05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L
M<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*
M=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S
M5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D
M7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@
M)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L
M("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF
M("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@
M97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G
M*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L
M;V=F:"P@(CX^(BP@)#(@;W(@9&EE('%Q6T-A;B=T(&]P96X@;&]G(&9I;&4@
M(B0R(CH@)"%=.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@
M/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD
M>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*
M<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL
M97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6
M.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF
M("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E
M.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]('-H:69T
M*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY
M("1F:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@9FEN9"!P87(@
M9FEL92`B)'!A<B(Z("0A73L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II
M<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA
M;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R
M(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<&%R(ET["GT*
M;7D@)6UE=&%?<&%R(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D
M>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A
M<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H
M6UXZ72LI.B`H+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE9"`D<&%R*2!["F]P
M96X@;7D@)'!H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!R96%D
M('!A<B!F:6QE("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR96%D("1P:"P@)&)U
M9BP@-#L*9&EE('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@9FEL95T@=6YL97-S
M("1B=68@97$@(E!+7#`P,UPP,#0B.PIC;&]S92`D<&@["GT*0W)E871E4&%T
M:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&
M:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&
M:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE('%Q6T-A;B=T(&-R96%T
M92!F:6QE("(D;W5T(CH@)"%=.PHD9F@M/F)I;FUO9&4H*3L*<V5E:R!?1D@L
M(#`L(#`["FUY("1L;V%D97(["FEF("AD969I;F5D("1D871A7W!O<RD@>PIR
M96%D(%]&2"P@)&QO861E<BP@)&1A=&%?<&]S.PI](&5L<V4@>PIL;V-A;"`D
M+R`]('5N9&5F.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!4E]6
M15)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E
M<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D
M4W1R:7`M/F%P<&QY*%PD;&]A9&5R+"`D,"D["GT*:68@*"1M971A7W!A<GMC
M;&5A;GTI('L*;7D@)'!A<E]C;&5A;B`]("(],2(["FUY("1P87-S7W!A<E]C
M;&5A;B`]('5C(")?7W!A<W-?<&%R7V-L96%N7U\B.PHD;&]A9&5R(#U^('-[
M*#\\/21[<&%S<U]P87)?8VQE86Y]*2@@*RE]"GLD<&%R7V-L96%N("X@*"(@
M(B!X("AL96YG=&@H)#$I("T@;&5N9W1H*"1P87)?8VQE86XI*2E]96<["GT*
M)&9H+3YP<FEN="@D;&]A9&5R*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!L
M;V%D97(@=&\@(B1O=70B.B`D(5T["FEF("@D8G5N9&QE*2!["G)E<75I<F4@
M4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII
M;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@
M>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH
M)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D
M0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["G-\+RM\+WQG
M+"!S?"\D?'P@9F]R96%C:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK
M*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@
M)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[
M("`@("`@("`@(R!86%@@;&EB7V5X="!V<R!D;&5X="`_"FUY("5W<FET=&5N
M.PIF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1F
M:6QE+"`D;F%M92D["FEF("AD969I;F5D*&UY("1F8R`]("1005(Z.DAE879Y
M.CI&=6QL0V%C:&5[)&ME>7TI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL
M("1F8RD["GT*96QS92!["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H
M)&ME>2`]?B!M?%Y<421D:7)<12\H+BHI)'QI*2!["B@D9FEL92P@)&YA;64I
M(#T@*"1K97DL("0Q*3L*;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO;&]A9&5R
M+UM>+UTK+R@N*BDD?"D@>PII9B`H;7D@)')E9B`]("1-;V1U;&5#86-H97LD
M,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"FEF
M("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B
M+"`D,2D["FQA<W0["GT*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M
M93L*;F5X="!I9B`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F
M:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO=71S*'-P
M<FEN=&8H<7%;4&%C:VEN9R!&24Q%("(E<R(N+BY=+"!R968@)&9I;&4@/R`D
M9FEL92T^>VYA;65](#H@)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF("AR968H
M)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIL
M;V-A;"`D+R`]('5N9&5F.PIO<&5N(&UY("1T:"P@)SPZ<F%W)RP@)&9I;&4@
M;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE(CH@)"%=.PHD8V]N=&5N="`]
M(#PD=&@^.PIC;&]S92`D=&@["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P
M;'DH7"1C;VYT96YT+"`B/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!
M4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*
M4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E
M;G0L("1F:6QE+"`D;F%M92D["GT*)&9H+3YP<FEN="@B1DE,12(L"G!A8VLH
M)TXG+"!L96YG=&@H)&YA;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O)7,B+"!!
M<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE*2P*
M<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI+`HD8V]N=&5N="D*;W(@9&EE
M('%Q6T5R<F]R('=R:71I;F<@96UB961D960@1DE,12!T;R`B)&]U="(Z("0A
M73L*;W5T<RAQ<5M7<FET=&5N(&%S("(D;F%M92)=*3L*?0I]"FEF("@D>FEP
M*2!["B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@/3T@07)C:&EV93HZ
M6FEP.CI!6E]/2PIO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!Z:7`@<&%R="!O
M9B`B)&]U=")=.PI]"B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE
M+"`P+"`D8V%C:&5?;F%M95]S:7IE.PII9B`H(21C86-H95]N86UE(&%N9"!M
M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;.5TI('L*;7D@)&-T>"`]($1I9V5S
M=#HZ4TA!+3YN97<H,2D["F]P96X@;7D@)'1H+"`B/#IR87<B+"`D;W5T.PHD
M8W1X+3YA9&1F:6QE*"1T:"D["F-L;W-E("1T:#L*)&-A8VAE7VYA;64@/2`D
M8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@D8V%C
M:&5?;F%M95]S:7IE("T@;&5N9W1H("1C86-H95]N86UE*3L*)&-A8VAE7VYA
M;64@+CT@)&-A8VAE7VUA<FME<CL*;7D@)&]F9G-E="`]("1F:"T^=&5L;"`K
M(&QE;F=T:"@D8V%C:&5?;F%M92D@+2!L96YG=&@H)&QO861E<BD["B1F:"T^
M<')I;G0H)&-A8VAE7VYA;64L"G!A8VLH)TXG+"`D;V9F<V5T*2P*)%!!4E]-
M04=)0RD*)B8@)&9H+3YC;&]S90IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!T
M<F%I;&5R(&]F("(D;W5T(CH@)"%=.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET
M.PI]"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R
M;V=N86UE*"D["G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA
M;&]A9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI
M=F4Z.EII<#L*?0IM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.R`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(R!!<F-H:79E.CI::7`@;W!E<F%T97,@;VX@
M86X@24\Z.DAA;F1L90HD9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O
M<B!D:64@<7%;9F1O<&5N*"D@9F%I;&5D.B`D(5T["D%R8VAI=F4Z.EII<#HZ
M<V5T0VAU;FM3:7IE*"US(%]&2"D["FUY("1Z:7`@/2!!<F-H:79E.CI::7`M
M/FYE=SL**"1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M
M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@
M<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!R;V=N86UE(ET["D%R8VAI=F4Z.EII
M<#HZ<V5T0VAU;FM3:7IE*#8T("H@,3`R-"D["G!U<V@@0%!!4CHZ3&EB0V%C
M:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PIO
M=71S*")%>'1R86-T:6YG('II<"XN+B(I.PII9B`H9&5F:6YE9"`D14Y6>U!!
M4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R
M96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D
M;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E
M<BT^9FEL94YA;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>
M"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PHH/SHD
M0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@
M)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E
M8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF
M("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S
M<V5D4VEZ92@I*2!["F]U=',H<7%;4VMI<'!I;F<@(B1M96UB97)?;F%M92(@
M<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B72D["GT@
M96QS92!["F]U=',H<7%;17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B
M)&1E<W1?;F%M92(N+BY=*3L**"1M96UB97(M/F5X=')A8W14;T9I;&5.86UE
M9"@D9&5S=%]N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I
M92!Q<5M%<G)O<B!E>'1R86-T:6YG('II<"!M96UB97(@=&\@(B1D97-T7VYA
M;64B73L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X
M(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI
M('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB
M+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P
M<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*
M+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T
M*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*
M<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L
M("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<
M+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T
M:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H
M(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR
M97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S
M=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER
M92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR
M97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q
M=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z
M.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U
M:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M
M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I
M9V5S=#HZ4TA!.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR
M97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R
M:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER
M92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E
M<75I<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T[
M"F5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L
M('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@
M<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A
M;"![(')E<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@
M*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^
M("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@
M;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$
M25(@5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I
M"BD@>PIN97AT('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A
M;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH
M)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@
M9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97
M:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD
M=7-E<FYA;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[
M55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*;7D@)'-T
M;7!D:7(@/2`B)'!A=&@D<WES>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@
M)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FUY("1C86-H95]D
M:7(["FEF("@D14Y6>U!!4E]#3$5!3GTI('L*)&-A8VAE7V1I<B`](")T96UP
M+20D(CL*?0IE;'-E('L*;W!E;B!M>2`D9F@L("(\.G)A=R(L("1P<F]G;F%M
M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE(CH@)"%=.PII9B`H
M*&UY("1M86=I8U]P;W,@/2!F:6YD7W!A<E]M86=I8R@D9F@I*2`^/2`P*2![
M"G-E96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L
M96YG=&@H)&-A8VAE7VUA<FME<BDL(#`["FUY("1B=68["G)E860@)&9H+"`D
M8G5F+"!L96YG=&@H)&-A8VAE7VUA<FME<BD["FEF("@D8G5F(&5Q("1C86-H
M95]M87)K97(I('L*<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S
M971?<VEZ90HM(&QE;F=T:"@D8V%C:&5?;6%R:V5R*0HM("1C86-H95]N86UE
M7W-I>F4L(#`["G)E860@)&9H+"`D8G5F+"`D8V%C:&5?;F%M95]S:7IE.PHD
M8G5F(#U^(',O7#`O+V<["B1C86-H95]D:7(@/2`B8V%C:&4M)&)U9B(["GT*
M?0IC;&]S92`D9F@["GT*:68@*"$D8V%C:&5?9&ER*2!["B1C86-H95]D:7(@
M/2`B=&5M<"TD)"(["B1%3E9[4$%27T-,14%.?2`](#$["GT*)'-T;7!D:7(@
M+CT@(B1S>7-[7V1E;&EM?21C86-H95]D:7(B.PIM:V1I<B`D<W1M<&1I<BP@
M,#<U-3L*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;&%S=#L*?0HD<&%R
M7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-
M4'T@/7X@+R@N*RDO.PI]"G-U8B!?<V%V95]A<R!["FUY("@D;F%M92P@)&-O
M;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M
M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M
M92`]("(D9G5L;&YA;64N)"0B.PIM>2`D9F@["BAO<&5N("1F:"P@)SXZ<F%W
M)RP@)'1E;7!N86UE*0HF)B`H<')I;G0@)&9H("1C;VYT96YT<RD*)B8@*&-L
M;W-E("1F:"D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@(B1T96UP;F%M92(Z
M("0A73L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E
M.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M
M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA
M;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[
M4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*
M)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E
M>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M
M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1S>7-[
M7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I
M;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E
M;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@[
M"GT*:68@*"US("(D<')O9VYA;64D<WES>U]E>&5](BD@>PHD<')O9VYA;64@
M+CT@)'-Y<WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS
M<&QI="`O7%$D<WES>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT
M(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!
M4E]414U0?3L*)&1I<B`]?B!S+UQ1)'-Y<WM?9&5L:6U]7$4D+R\["B@H)'!R
M;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5]
M(BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y
M<WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O
M9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA
M;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\
M?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D
M<WES>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1S>7-[7V1E;&EM
M?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W
M9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D
M*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P
M<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)'-Y<WM?9&5L:6U]7$4I+R1P=V0D
M<WES>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64[
M"GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)
M6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)
M5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@
M1$5"54<@0T%#2$4@4%)/1TY!344@*2`I('L*9&5L971E("1%3E9[(E!!4E\D
M7R)].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*
M)$5.5GLB4$%27R1?(GT@/2`D14Y6>R)005)?1TQ/0D%,7R1?(GT@:68@97AI
M<W1S("1%3E9[(E!!4E]'3$]"04Q?)%\B?3L*?0II9B`H)$5.5GM005)?5$5-
M4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*?0I]"G-U8B!O=71S('L*
M<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@
M(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I
M;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L
M(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV
M;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V
M96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU
M;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A
M<E]A<F=S*3L*9&EE('%Q6W!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP
M="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN70IU
M;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H
M)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I
M9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H
M)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*
M9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH`````
M<&5R;'AS:2YC``````````$;`SL```#<````&O__@K@```5\__^%"````/C_
M_X8````!*/__AN````&(__^'<````;C__XC8```!]/__B<@```(P__^,:```
M`G#__XS@```"K/__C2````+,__^-^````PC__XX````#'/__D"@```-8__^0
M8````X3__Y%P```#R/__EU````/\__^7X```!"C__Y@0```$2/__F2````2H
M__^@R```!/S__Z-8```%./__I&@```7`__^[Z```!@#__[Q8```&)/__O9``
M``9@__^^V```!I@`````````%``````!>E(``7@.`1L,#Z`!!PX`````%```
M`!S__X0(````0@``````````````%``````!>E(``7@.`1L,#Z`!````````
M7````!S__X30````W`!&A@Z'#8@,B0N*"HL)C`B-!XX&CP5&#L`"`I@*S\[-
MS,O*R<C'Q@Z@`4(+7`K/SLW,R\K)R,?&#J`!0@M."L_.S<S+RLG(Q\8.H`%"
M"P``````+````'S__X50````C@!&B@J+"8P(C0>.!H\%1@[8`P)Z"L_.S<S+
MR@Z@`4(+````.````*S__X6P```!8@!&A@Z'#8@,B0N*"HL)C`B-!XX&CP5&
M#N`#=`K/SLW,R\K)R,?&#J`!0@L`````.````.C__X;<````\`!&APV(#(D+
MB@J+"8P(C0>.!H\%1@[((@*4"L_.S<S+RLG(QPZ@`4(+````````/````23_
M_X>0```"G`!&A@Z'#8@,B0N*"HL)C`B-!XX&CP5&#M@"`P%D"L_.S<S+RLG(
MQ\8.H`%""P```````#@```%D__^)\````'@`1H8.APV(#(D+B@J+"8P(C0>.
M!H\%1@[(`@)JS\[-S,O*R<C'Q@Z@`0```````!P```&@__^*+````#P`3(X&
MCP5&#L`"9,_.#J`!````.````<#__XI,````U`!&A@Z'#8@,B0N*"HL)C`B-
M!XX&CP5&#MA"`K@*S\[-S,O*R<C'Q@Z@`4(+````$````?S__XKH````!@``
M```````X```"$/__BMP```(D`$:&#H<-B`R)"XH*BPF,"(T'C@:/!48.\","
M=@K/SLW,R\K)R,?&#J`!0@L````H```"3/__C,@````V`$J+"8P(C0>.!H\%
M1@[``F#/SLW,RPZ@`0```````$````)X__^,U````0P`1HD+B@J+"8P(C0>.
M!H\%1@[((@+&"L_.S<S+RLD.H`%""UP*S\[-S,O*R0Z@`48+````````,```
M`KS__XV@```%W`!&B@J+"8P(C0>.!H\%1@[0`@,%G`K/SLW,R\H.H`%&"P``
M`````"@```+P__^33````)``1HL)C`B-!XX&CP5&#M`"=@K/SLW,RPZ@`4(+
M````'````QS__Y.P````+@!&C@:/!48.P`)@S\X.H`$```!<```#//__D\``
M``$*`$:&#H<-B`R)"XH*BPF,"(T'C@:/!48.X`("6@K/SLW,R\K)R,?&#J`!
M0@M:"L_.S<S+RLG(Q\8.H`%&"P)V"L_.S<S+RLG(Q\8.H`%&"P````!0```#
MG/__E'````>D`%2&#H<-B`R)"XH*BPF,"(T'C@:/!48.J(4"`P*$"L_.S<S+
MRLG(Q\8.H`%""P,"P@K/SLW,R\K)R,?&#J`!1@L````````X```#\/__F\0`
M``**`$:'#8@,B0N*"HL)C`B-!XX&CP5&#M`"`P'V"L_.S<S+RLG(QPZ@`4(+
M``````!````$+/__GA@```$0`$:)"XH*BPF,"(T'C@:/!48.T`(">@K/SLW,
MR\K)#J`!0@L";`K/SLW,R\K)#J`!1@L``````$````1P__]]-````E``1H8.
MAPV(#(D+B@J+"8P(C0>.!H\%1@[H`@,!J`K/SLW,R\K)R,?&#J`!0@L`````
M````````/```!+3__YZ@```7@`!.A@Z'#8@,B0N*"HL)C`B-!XX&CP5&#M`'
M`Q=<"L_.S<S+RLG(Q\8.H`%""P```````"````3T__^UX````&P`2HX&CP5&
M#L`"`EK/S@Z@`0```````#@```48__^V+````3@`3(8.APV(#(D+B@J+"8P(
MC0>.!H\%7@[``@*N"L_.S<S+RLG(Q\8.H`%""P```#0```54__^W*````48`
M1H@,B0N*"HL)C`B-!XX&CP5L#L`"`J8*S\[-S,O*R<@.H`%&"P``````$```
M!8S__[@X````#```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````(X@````````C0``````````!`````````M$``````````0``
M``````+A``````````P````````9"``````````-````````7'@`````````
M&0```````+O``````````!L`````````"``````````:````````N\@`````
M````'``````````(`````&___O4````````"D``````````%````````#"``
M````````!@````````-H``````````H````````$20`````````+````````
M`!@`````````%0````````````````````,```````"]T``````````"````
M````!2@`````````%``````````'`````````!<````````3X``````````'
M````````$8@`````````"`````````)8``````````D`````````&```````
M```>``````````@`````;___^P`````(```!`````&____X````````1*```
M``!O____``````````$`````;___\````````!!J`````&____D`````````
M#@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````N]``
M````````````````````````````&78````````9E@```````!FV````````
M&=8````````9]@```````!H6````````&C8````````:5@```````!IV````
M````&I8````````:M@```````!K6````````&O8````````;%@```````!LV
M````````&U8````````;=@```````!N6````````&[8````````;U@``````
M`!OV````````'!8````````<-@```````!Q6````````''8````````<E@``
M`````!RV````````'-8````````<]@```````!T6````````'38````````=
M5@```````!UV````````'98````````=M@```````!W6````````'?8`````
M```>%@```````!XV````````'E8````````>=@```````!Z6````````'K8`
M```````>U@```````![V````````'Q8````````?-@```````!]6````````
M'W8````````?E@```````!^V````````']8````````?]@```````"`6````
M````(#8`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````($@``````````````````,`(_____P````````````!?@@``
M`````%T$``````````````````!=I````````%VH````````7W8```````!=
M"@```````%]^``````````````````!?9@```````%]L````````````````
M``!?B$=#0SH@*$1E8FEA;B`Q,BXR+C`M,2D@,3(N,BXP```N<VAS=')T86(`
M+FEN=&5R<``N;F]T92YG;G4N8G5I;&0M:60`+FYO=&4N04))+71A9P`N9VYU
M+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I
M;VY?<@`N<F5L82YD>6X`+G)E;&$N<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR
M;V1A=&$`+F5H7V9R86UE7VAD<@`N96A?9G)A;64`+FEN:71?87)R87D`+F9I
M;FE?87)R87D`+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S`"YC;VUM96YT````
M````````````````````````````````````````````````````````````
M```````````````````````````+`````0`````````"`````````C@`````
M```".``````````/`````````````````````0``````````````$P````<`
M`````````@````````)(`````````D@`````````)```````````````````
M``0``````````````"8````'``````````(````````";`````````)L````
M`````"`````````````````````$```````````````T;___]@`````````"
M`````````I`````````"D`````````#8````!0``````````````"```````
M````````/@````L``````````@````````-H`````````V@````````(N```
M``8````"``````````@`````````&````$8````#``````````(````````,
M(`````````P@````````!$D````````````````````!``````````````!.
M;____P`````````"````````$&H````````0:@````````"Z````!0``````
M`````````@`````````"````6V____X``````````@```````!$H````````
M$2@`````````8`````8````!``````````@``````````````&H````$````
M``````(````````1B````````!&(`````````E@````%```````````````(
M`````````!@```!T````!`````````!"````````$^`````````3X```````
M``4H````!0```!4`````````"``````````8````?@````$`````````!@``
M`````!D(````````&0@`````````0`````````````````````0`````````
M`````'D````!``````````8````````92````````!E(````````!P``````
M```````````````$`````````"````"$`````0`````````&````````($@`
M```````@2````````#PP````````````````````"```````````````B@``
M``$`````````!@```````%QX````````7'@`````````+```````````````
M``````0``````````````)`````!``````````(```````!<J````````%RH
M````````0.@````````````````````(``````````````"8`````0``````
M```"````````G9````````"=D`````````#<````````````````````!```
M````````````I@````$``````````@```````)YP````````GG`````````%
MT`````````````````````@``````````````+`````.``````````,`````
M``"[P````````*O```````````@````````````````````(``````````@`
M``"\````#P`````````#````````N\@```````"KR``````````(````````
M````````````"``````````(````R`````8``````````P```````+O0````
M````J]`````````"``````8```````````````@`````````$````-$````!
M``````````,```````"]T````````*W0`````````C``````````````````
M```(``````````@```#6`````0`````````#````````P`````````"P````
M``````"`````````````````````"```````````````W`````@`````````
M`P```````,"`````````L(``````````*`````````````````````@`````
M`````````.$````!`````````#```````````````````+"``````````!X`
M```````````````````!``````````$````!`````P``````````````````
J``````````"PG@````````#J`````````````````````0``````````
